Module context

Module context 

Modules

bbox
dungeon
geometry
light
linedef
meta
mini
organic
particle
pixelsource
sector
softrig
surface
tile
tilesource
vertex

Structs

Map
ServerContext
This gives context to the server of the editing state for live highlighting.

Enums

AvatarAnchorEditSlot
ContentContext
EditingGeoFilter
EditorViewMode
GeometryEditMode
GizmoMode
MapCamera
MapContext
MapToolType
PixelEditingContext
Identifies which texture is currently being edited by editor tools. This abstraction allows the same draw/fill/pick tools to work on any paintable texture source (tiles, avatar frames, future types). Each variant also determines how colors are resolved for painting.
ProjectContext
Value
VertexBlendPreset