Module surface

Module surface 

Structs

Attachment
Represents an attachment with a transform relative to a surface and optional mesh or procedural references.
Basis3
Represents a 3D basis with right, up, and normal vectors.
EditPlane
Defines an editable plane with origin, axes for 2D editing, and a scale factor.
ExtrusionSpec
How this surface turns into 3D geometry.
Plane
Represents a geometric plane defined by an origin and a normal vector.
ProfileLoop
One closed loop in the surface’s UV/profile space.
Surface
Represents a surface with the sector owner, geometry, and profile.

Enums

BillboardAnimation
Animation type for billboards
ExtrudeUV
UV mapping strategy for extruded side walls and caps.
ExtrusionMode
LoopOp
Operation applied to a profile loop on this surface (non-destructive).