pub struct Tile {
pub id: Uuid,
pub role: TileRole,
pub textures: Vec<Texture>,
pub module: Option<Module>,
pub blocking: bool,
pub scale: f32,
pub tags: String,
pub particle_emitter: Option<ParticleEmitter>,
pub light_emitter: Option<TileLightEmitter>,
}Fields
id: Uuidrole: TileRoletextures: Vec<Texture>The textures of the tiles. Primary source.
module: Option<Module>The module if the textures are shader generated
blocking: boolFor top down 2D scenarios
scale: f32The scale of the tile (mostly used for billboard rendering)
Tags
particle_emitter: Option<ParticleEmitter>Optional particle emitter definition derived from a tilegraph output.
light_emitter: Option<TileLightEmitter>Optional point light definition derived from a tilegraph output.
Implementations
Sourceimpl Tile
impl Tile
Sourcepub fn from_texture(texture: Texture) -> Tile
pub fn from_texture(texture: Texture) -> Tile
Create a tile from a single texture.
Sourcepub fn from_textures(textures: Vec<Texture>) -> Tile
pub fn from_textures(textures: Vec<Texture>) -> Tile
Create a tile from a vector of textures.
Sourcepub fn to_buffer_array(&self) -> Vec<Vec<u8>>
pub fn to_buffer_array(&self) -> Vec<Vec<u8>>
Converts the frames to an array of buffers
Sourcepub fn to_material_array(&self) -> Vec<Vec<u8>>
pub fn to_material_array(&self) -> Vec<Vec<u8>>
Converts the frames to an array of material buffers
Sourcepub fn resized(&self, new_width: usize, new_height: usize) -> Tile
pub fn resized(&self, new_width: usize, new_height: usize) -> Tile
Returns a new Tile with all textures resized to the specified dimensions
Sourcepub fn set_frames(&mut self, frames: usize)
pub fn set_frames(&mut self, frames: usize)
Sets the number of frames in the textures array. If frames > current count: duplicates the last texture to fill. If frames < current count: truncates the array. Also handles material_map and normal_map within each texture.
Sourcepub fn set_default_materials(&mut self)
pub fn set_default_materials(&mut self)
Initialize all textures with default materials and compute normals Sets roughness=0.5, metallic=0.0, opacity=1.0, emissive=0.0 for all pixels Then generates normals from the color data for each texture