pub enum ServerMessage {
PlayerJoined(Uuid, Uuid, Uuid),
}Expand description
Messages to the clients. The first argument is always the client id.
Variants
PlayerJoined(Uuid, Uuid, Uuid)
The given player instance has joined the server in the given region. The client will use this to know what player / region to draw / focus on.