pub struct Sector {
pub id: u32,
pub creator_id: Uuid,
pub name: String,
pub linedefs: Vec<u32>,
pub properties: ValueContainer,
pub shader: Option<Uuid>,
pub layer: Option<u8>,
}Fields
id: u32creator_id: Uuidname: Stringlinedefs: Vec<u32>properties: ValueContainershader: Option<Uuid>layer: Option<u8>The rect tool layer for this sector (if created by the rect tool).
Implementations
Sourceimpl Sector
impl Sector
pub fn new(id: u32, linedefs: Vec<u32>) -> Sector
Sourcepub fn vertices_world(&self, map: &Map) -> Option<Vec<Vec3<f32>>>
pub fn vertices_world(&self, map: &Map) -> Option<Vec<Vec3<f32>>>
Returns the sector’s vertices in world space as Vec<Vec3
Sourcepub fn y_span(&self, map: &Map) -> Option<(f32, f32)>
pub fn y_span(&self, map: &Map) -> Option<(f32, f32)>
Returns the vertical span (min_y, max_y) of this sector in world space.
Sourcepub fn intersects_vertical_slice(
&self,
map: &Map,
slice_y: f32,
thickness: f32,
) -> bool
pub fn intersects_vertical_slice( &self, map: &Map, slice_y: f32, thickness: f32, ) -> bool
Checks whether this sector intersects a vertical slice centered at slice_y with thickness thickness.
pub fn bounding_box(&self, map: &Map) -> BBox
Sourcepub fn center_3d(&self, map: &Map) -> Option<Vec3<f32>>
pub fn center_3d(&self, map: &Map) -> Option<Vec3<f32>>
Calculate the center of the sector using 3D coords.
Sourcepub fn generate_geometry(
&self,
map: &Map,
) -> Option<(Vec<[f32; 2]>, Vec<(usize, usize, usize)>)>
pub fn generate_geometry( &self, map: &Map, ) -> Option<(Vec<[f32; 2]>, Vec<(usize, usize, usize)>)>
Generate geometry (vertices and indices) for the polygon using earcutr
Sourcepub fn is_inside(&self, map: &Map, point: Vec2<f32>) -> bool
pub fn is_inside(&self, map: &Map, point: Vec2<f32>) -> bool
Checks if a point is inside the sector polygon using the ray-casting algorithm.
Sourcepub fn signed_distance(&self, map: &Map, point: Vec2<f32>) -> Option<f32>
pub fn signed_distance(&self, map: &Map, point: Vec2<f32>) -> Option<f32>
Generate the signed distance to the